#
# spec file for package python-drms
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-drms
Version:        0.8.0
Release:        1.1
Summary:        Tool to access HMI, AIA and MDI data with Python
License:        MIT
URL:            https://github.com/sunpy/drms
Source:         https://files.pythonhosted.org/packages/source/d/drms/drms-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.9}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-numpy
Requires:       python-pandas
Requires(postun): update-alternatives
Requires(post): update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module astropy}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pandas}
BuildRequires:  %{python_module pytest-astropy}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
The drms module provides an interface for accessing HMI, AIA and MDI
data with Python. It uses the publicly accessible JSOC DRMS server by
default, but can also be used with local NetDRMS sites.

%prep
%setup -q -n drms-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/drms
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%post
%python_install_alternative drms

%postun
%python_uninstall_alternative drms

%files %{python_files}
%doc CITATION.rst README.rst
%license LICENSE.rst
%python_alternative %{_bindir}/drms
%{python_sitelib}/drms
%{python_sitelib}/drms-%{version}*-info

%changelog
* Sat Aug 31 2024 Dirk Müller <dmueller@suse.com>
- update to 0.8.0:
  * Increased minimum version of Python to 3.10.0
  * The return from drms.JsocInfoConstants is now a string, there
    is no need to do .value on it.
* Mon Jan  8 2024 Dirk Müller <dmueller@suse.com>
- update to 0.7.1:
  * Incorrect setup of the logger is now fixed.
  * Fixed missing environment variable in the docs.
* Sat Nov 25 2023 Dirk Müller <dmueller@suse.com>
- update to 0.7.0:
  * Dropped Python 3.8 support.
  * Updated all of the sphinx anchors to be more consistent.
  * This means that any use of the old anchors (intersphinx links
    to sunpy doc pages) will need to be updated.
  * Removed ``verbose`` keyword argument from `drms.Client`.
  * Now all prints are done via the logging module.
  * ``drms.const`` was renamed to `drms.JsocInfoConstants`
  * Renamed keywords or arguments from ``requestor`` to
    ``requester``.
  * Removed ``debug`` keyword argument from `drms.HttpJsonClient`
  * Now all prints are done via the logging module.
  * Removed all FTP options.
  * All keywords have to be passed by reference, no more
    positional keywords arguments are allowed.
  * Added "ruff" to the pre-commit and fixed the errors.
* Tue Jun 27 2023 Markéta Machová <mmachova@suse.com>
- Update to 0.6.4
  * Modified `drms.client.Client._convert_numeric_keywords` to use
    a row-centric approach for handling hexadecimal strings.
  * Modified `drms.utils.to_datetime` to work with Pandas 2.0.
* Thu Aug  5 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.6.2
  * Python 2 support has been dropped, only Python 3.7 or higher is
    supported.
  * Client.get() has been removed, use `drms.client.Client.query()`
    instead.
  * `drms.client.Client.export` now accepts a process keyword
    argument. This allows users to specify additional server-side
    processing options such as image cutouts. See the "Processing"
    section of the JSOC Data Export page for more information.
* Wed Apr 21 2021 Steve Kowalik <steven.kowalik@suse.com>
- Do not build for Python 3.6, due to no NumPy.
* Wed Nov 20 2019 Todd R <toddrme2178@gmail.com>
- Use github source
* Tue Nov 19 2019 Todd R <toddrme2178@gmail.com>
- Update to version 0.5.7
  * Updated examples and documentation
  * Fixed some pandas future warnings
  * Added JOSS paper
* Fri Jul 26 2019 Todd R <toddrme2178@gmail.com>
- Initial version
